@@ -64,11 +64,12 @@ use Moose::Role;
 use namespace::autoclean;
 
 # ABSTRACT: Have text templating capabilities in your Dist::Zilla plugin
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 with 'Dist::Zilla::Role::ErrorLogger' => { -version => 0.005 };
 
 use Text::Template qw{};
+use Carp qw{ croak };
 
 # --------------------------------------------------------------------------------------------------
 
@@ -76,10 +77,10 @@ use Text::Template qw{};
 #pod
 #pod Pair of open and closing delimiters the code fragments surrounded by.
 #pod
-#pod Attribute introduces F<dist.ini> option with the same name. Option value will be split (see
-#pod C<BUILDARGS>) to initialize the attribute.
+#pod Attribute introduces F<dist.ini> option with the same name. Option value will be split on
+#pod whitespaces (and result should ) to initialize the attribute.
 #pod
-#pod ArrayRef[Str], read-only. Default value is '{{', '}}'.
+#pod C<Str|ArrayRef[Str]>, read-only. Default value is C<[ '{{', '}}' ]>.
 #pod
 #pod See C<DELIMITERS> option of L<Text::Template/"fill_in">.
 #pod
@@ -89,10 +90,23 @@ use Text::Template qw{};
 #pod =cut
 
 has delimiters => (
-  is            => 'ro',
-  isa           => 'ArrayRef[Str]',
-  lazy          => 1,
-  default       => sub { [ '{{', '}}' ] },
+    is          => 'ro',
+    isa         => 'Str|ArrayRef[Str]',
+    lazy        => 1,
+    default     => sub { [ '{{', '}}' ] },
+    trigger     => sub {
+        my ( $self, $new ) = @_;
+        if ( not ref( $new ) ) {
+            $new =~ s{\A\s+}{};     # Drop leading ws, or `split` may leave the first item empty.
+            $new = [ split( qr{\s+}, $new ) ];
+            @$new == 2
+                or croak "\"delimiters\" value must be Str of *two* whitespace-separated words";
+            $self->{ delimiters } = $new;
+        } else {
+            @$new == 2
+                or croak "\"delimiters\" value must be ArrayRef with *two* elements";
+        };
+    },
 );
 
 # --------------------------------------------------------------------------------------------------
@@ -190,23 +204,6 @@ sub _build_broken {
 
 # --------------------------------------------------------------------------------------------------
 
-#pod =Method BUILDARGS
-#pod
-#pod The method splits C<delimiters> option value into list of words to initialize C<delimiters>
-#pod attribute (which is of C<ArrayRef[Str]> type).
-#pod
-#pod =cut
-
-around BUILDARGS => sub {
-    my ( $orig, $class, $args ) = @_;
-    if ( exists( $args->{ delimiters } ) ) {
-        $args->{ delimiters } = [ split( m{\s+}, $args->{ delimiters } ) ];
-    };
-    return $class->$orig( $args );
-};
-
-# --------------------------------------------------------------------------------------------------
-
 #pod =method mvp_multivalue_args
 #pod
 #pod The method tells C<Dist::Zilla> that C<prepend> is a multi-value option.
@@ -317,11 +314,12 @@ sub fill_in_string {
 #pod
 #pod =head1 SEE ALSO
 #pod
-#pod L<Dist::Zilla>
-#pod L<Dist::Zilla::Role>
-#pod L<Dist::Zilla::Plugin>
-#pod L<Dist::Zilla::Role::TextTemplate>
-#pod L<Text::Template>
+#pod =for :list
+#pod = L<Dist::Zilla>
+#pod = L<Dist::Zilla::Role>
+#pod = L<Dist::Zilla::Plugin>
+#pod = L<Dist::Zilla::Role::TextTemplate>
+#pod = L<Text::Template>
 #pod
 #pod =cut
 
@@ -420,7 +418,7 @@ Dist::Zilla::Role::TextTemplater - Have text templating capabilities in your Dis
 
 =head1 VERSION
 
-Version 0.002, released on 2015-07-18 18:38 UTC.
+Version 0.003, released on 2015-07-22 12:56 UTC.
 
 =head1 WHAT?
 
@@ -458,23 +456,16 @@ reporting and some others are covered in the L<readme|Dist::Zilla::Role::TextTem
 The role provides consuming plugin with C<fill_in_string> method and bunch of accompanying
 attributes and F<dist.ini> options.
 
-=head1 CLASS METHODS
-
-=head2 BUILDARGS
-
-The method splits C<delimiters> option value into list of words to initialize C<delimiters>
-attribute (which is of C<ArrayRef[Str]> type).
-
 =head1 OBJECT ATTRIBUTES
 
 =head2 delimiters
 
 Pair of open and closing delimiters the code fragments surrounded by.
 
-Attribute introduces F<dist.ini> option with the same name. Option value will be split (see
-C<BUILDARGS>) to initialize the attribute.
+Attribute introduces F<dist.ini> option with the same name. Option value will be split on
+whitespaces (and result should ) to initialize the attribute.
 
-ArrayRef[Str], read-only. Default value is '{{', '}}'.
+C<Str|ArrayRef[Str]>, read-only. Default value is C<[ '{{', '}}' ]>.
 
 See C<DELIMITERS> option of L<Text::Template/"fill_in">.
 
@@ -631,11 +622,19 @@ does I<not> allow to specify C<package>.
 
 =head1 SEE ALSO
 
-L<Dist::Zilla>
-L<Dist::Zilla::Role>
-L<Dist::Zilla::Plugin>
-L<Dist::Zilla::Role::TextTemplate>
-L<Text::Template>
+=over 4
+
+=item L<Dist::Zilla>
+
+=item L<Dist::Zilla::Role>
+
+=item L<Dist::Zilla::Plugin>
+
+=item L<Dist::Zilla::Role::TextTemplate>
+
+=item L<Text::Template>
+
+=back
 
 =head1 AUTHOR
 
